<?php
/**
 * verscontabilidade functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package verscontabilidade
 */

if ( ! function_exists( 'verscontabilidade_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function verscontabilidade_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on verscontabilidade, use a find and replace
		 * to change 'verscontabilidade' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'verscontabilidade', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary', 'verscontabilidade' ),
			'footer-menu' => esc_html__( 'Footer', 'verscontabilidade' ),
			'mobile-menu' => esc_html__( 'Mobile', 'verscontabilidade' ),
			'blog-menu' => esc_html__( 'Blog', 'verscontabilidade' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'verscontabilidade_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );

		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
			'gallery',
			'audio',
		) );

		// THUMBNAILS
		add_image_size('verscontabilidade-featured-image', 760, 360, TRUE);
		add_image_size('post-home', 390, 230, TRUE);
		add_image_size('ebook-list', 200, 290, TRUE);

	}
endif;
add_action( 'after_setup_theme', 'verscontabilidade_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function verscontabilidade_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'verscontabilidade_content_width', 640 );
}
add_action( 'after_setup_theme', 'verscontabilidade_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function verscontabilidade_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'verscontabilidade' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'verscontabilidade' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'verscontabilidade_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function verscontabilidade_scripts() {
	// CSS
	wp_enqueue_style('flammo-style', get_stylesheet_uri());
    wp_enqueue_style('bootstrap.min', get_template_directory_uri() . '/css/bootstrap.min.css');
    wp_enqueue_style('bootstrap-theme.min', get_template_directory_uri() . '/css/bootstrap-theme.min.css');
    wp_enqueue_style('flammo.lightbox', get_template_directory_uri() . '/css/flammo.lightbox.css');
    wp_enqueue_style('theme', get_template_directory_uri() . '/css/theme.min.css', array(), NULL);

    wp_enqueue_script( 'jquery' );
    wp_enqueue_script('jquery.touchSwipe.min', get_template_directory_uri() . '/js/jquery.touchSwipe.min.js');
    
    wp_enqueue_script('bootstrap.min', get_template_directory_uri() . '/js/bootstrap.min.js');
    wp_enqueue_script('flammo.lightbox', get_template_directory_uri() . '/js/flammo.lightbox.js');
    wp_enqueue_script('jquery.cycle.all', get_template_directory_uri() . '/js/jquery.cycle.all.js');
    wp_enqueue_script('jquery.validate.min', get_template_directory_uri() . '/js/jquery.validate.min.js');
    wp_enqueue_script('theme', get_template_directory_uri() . '/js/theme.js');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'verscontabilidade_scripts' );



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

// OPTIONS PAGES
if (function_exists('acf_add_options_page')) {
    acf_add_options_page(array('page_title' => 'Footer', 'menu_slug' => 'options-footer', 'position' => -100));
}


// HELPERS
require get_template_directory() . '/inc/form_helper.php';
require get_template_directory() . '/inc/text_helper.php';
require get_template_directory() . '/inc/send_email.php';

// [social-networks]
function social_networks_func( $atts ) {
	ob_start();
?>
	
	<h3 class="footer-title no-margin">Conecte-se a PEJOTA</h3>
	<?php $social_networks = get_field('social_networks', 'options'); ?>
	<?php if ($social_networks): ?>
		<ul class="social-networks">
			<?php foreach ($social_networks as $social): ?>
				<li><a href="<?php echo $social['link'] ?>" target="_blank" title="<?php echo $social['name'] ?>"><img alt="<?php echo $social['name'] ?>" src="<?php echo $social['icon']; ?>" alt=""></a></li>
			<?php endforeach ?>
		</ul>
	<?php endif ?>

	<div class="clearfix"></div>

	<?php if (get_field('facebook_footer', 'option')): ?>
		<?php the_field('facebook_footer', 'option'); ?>
	<?php endif ?>		
<?php
    $output_string = ob_get_contents();
	ob_end_clean();
	return $output_string;
}
add_shortcode( 'social-networks', 'social_networks_func' );

// [widget-cnpj]
function widget_cnpj_func( $atts ) {
	ob_start();
?>
	<div class="widget-cnpj">
		<img src="<?php echo get_template_directory_uri(); ?>/img/banner-texto-01.png" class="texto-01" alt="">
		<img src="<?php echo get_template_directory_uri(); ?>/img/banner-texto-02.png" class="texto-02" alt="">
	
		<a href="<?php echo get_permalink(7); ?>" class="btn-widget-cnpj"><img src="<?php echo get_template_directory_uri(); ?>/img/banner-bt-nao-tenho-cnpj.png" alt=""></a>
		<a href="<?php echo get_permalink(9); ?>" class="btn-widget-cnpj"><img src="<?php echo get_template_directory_uri(); ?>/img/banner-bt-ja-tenho-cnpj.png" alt=""></a>
	</div>
<?php
    $output_string = ob_get_contents();
	ob_end_clean();
	return $output_string;
}
add_shortcode( 'widget-cnpj', 'widget_cnpj_func' );


add_filter( 'widget_text', 'do_shortcode' );